@@ -12,6 +12,13 @@
 
 	----------------------------------------------------------------------------
  */
+
+/**
+ * File: BMP IO
+ *
+ * Read and write BMP images.
+ */
+
 /* $Id$ */
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -60,6 +67,21 @@ static int gdBMPPutInt(gdIOCtx *out, int w)
 	return 0;
 }
 
+/*
+	Function: gdImageBmpPtr
+
+	Outputs the given image as BMP data, but using a <gdIOCtx> instead
+	of a file. See <gdImageBmp>.
+
+	Parameters:
+		im			- the image to save.
+		size 		- Output: size in bytes of the result.
+		compression - whether to apply RLE or not.
+
+	Returns:
+
+		A pointer to memory containing the image data or NULL on error.
+*/
 BGD_DECLARE(void *) gdImageBmpPtr(gdImagePtr im, int *size, int compression)
 {
 	void *rv;
@@ -71,6 +93,34 @@ BGD_DECLARE(void *) gdImageBmpPtr(gdImagePtr im, int *size, int compression)
 	return rv;
 }
 
+/*
+	Function: gdImageBmp
+
+    <gdImageBmp> outputs the specified image to the specified file in
+    BMP format. The file must be open for writing. Under MSDOS and all
+    versions of Windows, it is important to use "wb" as opposed to
+    simply "w" as the mode when opening the file, and under Unix there
+    is no penalty for doing so. <gdImageBmp> does not close the file;
+    your code must do so.
+
+    In addition, <gdImageBmp> allows to specify whether RLE compression
+    should be applied.
+
+	Variants:
+
+		<gdImageBmpCtx> write via a <gdIOCtx> instead of a file handle.
+
+		<gdImageBmpPtr> store the image file to memory.
+
+	Parameters:
+
+		im			- the image to save.
+		outFile		- the output FILE* object.
+		compression - whether to apply RLE or not.
+
+	Returns:
+		nothing
+*/
 BGD_DECLARE(void) gdImageBmp(gdImagePtr im, FILE *outFile, int compression)
 {
 	gdIOCtx *out = gdNewFileCtx(outFile);
@@ -79,6 +129,17 @@ BGD_DECLARE(void) gdImageBmp(gdImagePtr im, FILE *outFile, int compression)
 	out->gd_free(out);
 }
 
+/*
+	Function: gdImageBmpCtx
+
+	Outputs the given image as BMP data, but using a <gdIOCtx> instead
+	of a file. See <gdImageBmp>.
+
+	Parameters:
+		im			- the image to save.
+		out 		- the <gdIOCtx> to write to.
+		compression - whether to apply RLE or not.
+*/
 BGD_DECLARE(void) gdImageBmpCtx(gdImagePtr im, gdIOCtxPtr out, int compression)
 {
 	int bitmap_size = 0, info_size, total_size, padding;
@@ -93,7 +154,7 @@ BGD_DECLARE(void) gdImageBmpCtx(gdImagePtr im, gdIOCtxPtr out, int compression)
 		compression = 0;
 	}
 
-	if (compression == 1 && !out->seek) {
+	if (compression && !out->seek) {
 		/* Try to create a temp file where we can seek */
 		if ((tmpfile_for_compression = tmpfile()) == NULL) {
 			compression = 0;
@@ -341,9 +402,7 @@ static int compress_row(unsigned char *row, int length)
 	}
 
 	if (compressed_run) {
-		if (rle_type == BMP_RLE_TYPE_RLE) {
-			compressed_length += build_rle_packet(row, rle_type, compressed_run, uncompressed_row);
-		}
+		compressed_length += build_rle_packet(row, rle_type, compressed_run, uncompressed_row);
 	}
 
 	gdFree(uncompressed_start);
@@ -397,6 +456,9 @@ static int build_rle_packet(unsigned char *row, int packet_type, int length, uns
 	return compressed_size;
 }
 
+/*
+	Function: gdImageCreateFromBmp
+*/
 BGD_DECLARE(gdImagePtr) gdImageCreateFromBmp(FILE * inFile)
 {
 	gdImagePtr im = 0;
@@ -407,6 +469,9 @@ BGD_DECLARE(gdImagePtr) gdImageCreateFromBmp(FILE * inFile)
 	return im;
 }
 
+/*
+	Function: gdImageCreateFromBmpPtr
+*/
 BGD_DECLARE(gdImagePtr) gdImageCreateFromBmpPtr(int size, void *data)
 {
 	gdImagePtr im;
@@ -417,6 +482,9 @@ BGD_DECLARE(gdImagePtr) gdImageCreateFromBmpPtr(int size, void *data)
 	return im;
 }
 
+/*
+	Function: gdImageCreateFromBmpCtx
+*/
 BGD_DECLARE(gdImagePtr) gdImageCreateFromBmpCtx(gdIOCtxPtr infile)
 {
 	bmp_hdr_t *hdr;
