@@ -5,6 +5,14 @@
  * http://www.csn.ul.ie/~caolan
  */
 
+
+/**
+ * File: XPM Input
+ *
+ * Read XPM images.
+ */
+
+
 #ifdef HAVE_CONFIG_H
 #	include "config.h"
 #endif
@@ -28,6 +36,43 @@ BGD_DECLARE(gdImagePtr) gdImageCreateFromXpm(char *filename)
 
 #include <X11/xpm.h>
 
+/*
+  Function: gdImageCreateFromXpm
+
+    <gdImageCreateFromXbm> is called to load images from XPM X Window
+    System color bitmap format files. This function is available only
+    if HAVE_XPM is selected in the Makefile and the Xpm library is
+    linked with the application. Unlike most gd file functions, the
+    Xpm functions *require filenames*, not file
+    pointers. <gdImageCreateFromXpm> returns a <gdImagePtr> to the new
+    image, or NULL if unable to load the image (most often because the
+    file is corrupt or does not contain an XPM bitmap format
+    image). You can inspect the sx and sy members of the image to
+    determine its size. The image must eventually be destroyed using
+    <gdImageDestroy>.
+
+  Parameters:
+
+    filename - The input filename (*not* FILE pointer)
+
+  Returns:
+
+    A pointer to the new image or NULL if an error occurred.
+
+  Example:
+    (start code)
+
+    gdImagePtr im;
+    FILE *in;
+    in = fopen("myxpm.xpm", "rb");
+    im = gdImageCreateFromXpm(in);
+    fclose(in);
+    // ... Use the image ...
+    gdImageDestroy(im);
+
+    (end code)
+
+*/
 BGD_DECLARE(gdImagePtr) gdImageCreateFromXpm(char *filename)
 {
 	XpmInfo info;
@@ -49,6 +94,16 @@ BGD_DECLARE(gdImagePtr) gdImageCreateFromXpm(char *filename)
 	if(overflow2(sizeof(int), number)) {
 		goto done;
 	}
+	for(i = 0; i < number; i++) {
+		/*
+		   avoid NULL pointer dereference
+		   TODO better fix need to manage monochrome/monovisual
+		   see m_color or g4_color or g_color
+		*/
+		if (!image.colorTable[i].c_color) {
+			goto done;
+		}
+	}
 
 	colors = (int *)gdMalloc(sizeof(int) * number);
 	if(colors == NULL) {
